pyrasa.irasa\_mne.irasa\_raw
============================

.. currentmodule:: pyrasa.irasa_mne

.. autofunction:: irasa_raw

.. _sphx_glr_backreferences_pyrasa.irasa_mne.irasa_raw:

.. minigallery:: pyrasa.irasa_mne.irasa_raw
    :add-heading: